pilot.coordination.advert_adaptor.AdvertCoordinationAdaptor

Package pilot :: Package coordination :: Module advert_adaptor :: Class AdvertCoordinationAdaptor |

# Class AdvertCoordinationAdaptor

source code

BigData persists its data in a central data space, e.g. the Advert service to facilitate distributed coordination:

advert://advert.cct.lsu.edu/pilot/3d0d5960-296d-11e1-8896-00264a13ca4c/data/ => namespace for pilot data

advert://advert.cct.lsu.edu/pilot/3d0d5960-296d-11e1-8896-00264a13ca4c/data/pds => pilot data service advert://advert.cct.lsu.edu/pilot/3d0d5960-296d-11e1-8896-00264a13ca4c/data/pds/pilot-data-description => pilot data description ...

advert://advert.cct.lsu.edu/pilot/3d0d5960-296d-11e1-8896-00264a13ca4c/data/pds/ => pilot store service advert://advert.cct.lsu.edu/pilot/3d0d5960-296d-11e1-8896-00264a13ca4c/data/pds/pilot-data-description => pilot data description

This class is stateless - the application's base_url needs to be passed into every method.

Class Methods
get_base_url(cls, application_id) | source code
add_pds(cls, application_url, pds) | source code
delete_pds(cls, pds_url) | source code
add_pd(cls, pds_url, pd) | source code
update_pd(cls, pd) | source code
get_pd(cls, pds_url) | source code
list_pd(cls, pds_url) return a list of urls to pd managed by the PDS | source code
delete_pd(cls, pds_url) | source code
add_cds(cls, application_url, cds) | source code
update_cds(cls, cds_url, cds) | source code
delete_cds(cls, cds_url) | source code
add_du(cls, dus_url, du) | source code
get_du(cls, du_url) | source code
update_du(cls, du) | source code
list_du(cls, dus_url) return a list of urls to du managed by the PDS | source code
delete_du(cls, du_url) | source code
get_pds_url(cls, application_url, pds_id) | source code
get_cds_url(cls, application_url, cds_id) | source code

Class Variables
| BASE_URL = `"advert://localhost/"`
| BASE_URL_QUERY_STRING = `"?dbtype=sqlite3"`
| PILOT_PATH = `"pilot"`
| PILOT_DATA_PATH = `"pilot"`
| PILOT_DATA_SERVICE_PATH = `PILOT_DATA_PATH+ "/pds"`
| DATA_UNIT_SERVICE_PATH = `PILOT_DATA_PATH+ "/dus"`
| COMPUTE_DATA_SERVICE_PATH = `PILOT_DATA_PATH+ "/cds"`